@@ -28,6 +28,7 @@ import java.util.regex.Pattern;
 
 import org.apache.tools.ant.AntClassLoader;
 import org.eclipse.jetty.util.PatternMatcher;
+import org.eclipse.jetty.util.URIUtil;
 import org.eclipse.jetty.util.resource.Resource;
 import org.eclipse.jetty.webapp.WebAppClassLoader;
 import org.eclipse.jetty.webapp.WebAppContext;
@@ -37,32 +38,31 @@ import org.eclipse.jetty.webapp.WebXmlConfiguration;
 public class AntWebInfConfiguration extends WebInfConfiguration
 {
 
-    
     @Override
     public void preConfigure(final WebAppContext context) throws Exception
-    {        
+    {
         //Make a temp directory for the webapp if one is not already set
         resolveTempDirectory(context);
-        
-        //Extract webapp if necessary
-        unpack (context);
 
-        
+        //Extract webapp if necessary
+        unpack(context);
+
         //Apply an initial ordering to the jars which governs which will be scanned for META-INF
         //info and annotations. The ordering is based on inclusion patterns.       
         String tmp = (String)context.getAttribute(WEBINF_JAR_PATTERN);
-        Pattern webInfPattern = (tmp==null?null:Pattern.compile(tmp));
+        Pattern webInfPattern = (tmp == null ? null : Pattern.compile(tmp));
         tmp = (String)context.getAttribute(CONTAINER_JAR_PATTERN);
-        Pattern containerPattern = (tmp==null?null:Pattern.compile(tmp));
+        Pattern containerPattern = (tmp == null ? null : Pattern.compile(tmp));
 
         //Apply ordering to container jars - if no pattern is specified, we won't
         //match any of the container jars
-        PatternMatcher containerJarNameMatcher = new PatternMatcher ()
+        PatternMatcher containerJarNameMatcher = new PatternMatcher()
         {
+            @Override
             public void matched(URI uri) throws Exception
             {
                 context.getMetaData().addContainerResource(Resource.newResource(uri));
-            }      
+            }
         };
         ClassLoader loader = context.getClassLoader();
         if (loader != null)
@@ -70,38 +70,38 @@ public class AntWebInfConfiguration extends WebInfConfiguration
             loader = loader.getParent();
             if (loader != null)
             {
-                URI[] containerUris = null; 
-           
+                URI[] containerUris = null;
+
                 if (loader instanceof URLClassLoader)
                 {
                     URL[] urls = ((URLClassLoader)loader).getURLs();
                     if (urls != null)
                     {
                         containerUris = new URI[urls.length];
-                        int i=0;
+                        int i = 0;
                         for (URL u : urls)
                         {
-                            try 
+                            try
                             {
                                 containerUris[i] = u.toURI();
                             }
                             catch (URISyntaxException e)
                             {
-                                containerUris[i] = new URI(u.toString().replaceAll(" ", "%20"));
-                            }  
+                                containerUris[i] = new URI(URIUtil.encodeSpaces(u.toString()));
+                            }
                             i++;
                         }
                     }
                 }
                 else if (loader instanceof AntClassLoader)
                 {
-                    AntClassLoader antLoader = (AntClassLoader)loader;     
+                    AntClassLoader antLoader = (AntClassLoader)loader;
                     String[] paths = antLoader.getClasspath().split(new String(new char[]{File.pathSeparatorChar}));
                     if (paths != null)
                     {
                         containerUris = new URI[paths.length];
-                        int i=0;
-                        for (String p:paths)
+                        int i = 0;
+                        for (String p : paths)
                         {
                             File f = new File(p);
                             containerUris[i] = f.toURI();
@@ -113,35 +113,34 @@ public class AntWebInfConfiguration extends WebInfConfiguration
                 containerJarNameMatcher.match(containerPattern, containerUris, false);
             }
         }
-        
+
         //Apply ordering to WEB-INF/lib jars
-        PatternMatcher webInfJarNameMatcher = new PatternMatcher ()
+        PatternMatcher webInfJarNameMatcher = new PatternMatcher()
         {
             @Override
             public void matched(URI uri) throws Exception
             {
                 context.getMetaData().addWebInfJar(Resource.newResource(uri));
-            }      
+            }
         };
         List<Resource> jars = findJars(context);
-       
+
         //Convert to uris for matching
         URI[] uris = null;
         if (jars != null)
         {
             uris = new URI[jars.size()];
-            int i=0;
-            for (Resource r: jars)
+            int i = 0;
+            for (Resource r : jars)
             {
                 uris[i++] = r.getURI();
             }
         }
         webInfJarNameMatcher.match(webInfPattern, uris, true); //null is inclusive, no pattern == all jars match 
-        
+
         //No pattern to appy to classes, just add to metadata
         context.getMetaData().setWebInfClassesDirs(findClassDirs(context));
     }
-    
 
     /**
      * Adds classpath files into web application classloader, and
@@ -149,6 +148,7 @@ public class AntWebInfConfiguration extends WebInfConfiguration
      *
      * @see WebXmlConfiguration#configure(WebAppContext)
      */
+    @Override
     public void configure(WebAppContext context) throws Exception
     {
         if (context instanceof AntWebAppContext)
@@ -156,11 +156,11 @@ public class AntWebInfConfiguration extends WebInfConfiguration
             List<File> classPathFiles = ((AntWebAppContext)context).getClassPathFiles();
             if (classPathFiles != null)
             {
-                for (File cpFile:classPathFiles)
+                for (File cpFile : classPathFiles)
                 {
                     if (cpFile.exists())
                     {
-                        ((WebAppClassLoader) context.getClassLoader()).addClassPath(cpFile.getCanonicalPath());
+                        ((WebAppClassLoader)context.getClassLoader()).addClassPath(cpFile.getCanonicalPath());
                     }
                 }
             }
