@@ -22,6 +22,7 @@ import java.nio.ByteBuffer;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.function.Supplier;
 
+import org.eclipse.jetty.http.BadMessageException;
 import org.eclipse.jetty.http.HttpFields;
 import org.eclipse.jetty.http.HttpStatus;
 import org.eclipse.jetty.http.HttpVersion;
@@ -110,6 +111,21 @@ public class HttpTransportOverHTTP2 implements HttpTransport
             {
                 if (commit.compareAndSet(false, true))
                 {
+                    if (lastContent)
+                    {
+                        long realContentLength = BufferUtil.length(content);
+                        long contentLength = info.getContentLength();
+                        if (contentLength < 0)
+                        {
+                            info.setContentLength(realContentLength);
+                        }
+                        else if (hasContent && contentLength != realContentLength)
+                        {
+                            callback.failed(new BadMessageException(HttpStatus.INTERNAL_SERVER_ERROR_500, String.format("Incorrect Content-Length %d!=%d", contentLength, realContentLength)));
+                            return;
+                        }
+                    }
+
                     if (hasContent)
                     {
                         Callback commitCallback = new Callback.Nested(callback)
@@ -239,7 +255,7 @@ public class HttpTransportOverHTTP2 implements HttpTransport
         if (LOG.isDebugEnabled())
             LOG.debug("HTTP/2 Push {}", request);
 
-        stream.push(new PushPromiseFrame(stream.getId(), 0, request), new Promise<Stream>()
+        stream.push(new PushPromiseFrame(stream.getId(), request), new Promise<Stream>()
         {
             @Override
             public void succeeded(Stream pushStream)
