@@ -27,6 +27,9 @@ import java.nio.file.Path;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
+
+import javax.servlet.ServletContextEvent;
+import javax.servlet.ServletContextListener;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
@@ -445,6 +448,22 @@ public class ContextHandlerTest
         assertThat(connector.getResponse("GET /foo/xxx HTTP/1.0\n\n"), Matchers.containsString("ctx='/foo'"));
         assertThat(connector.getResponse("GET /foo/bar/xxx HTTP/1.0\n\n"), Matchers.containsString("ctx='/foo/bar'"));
     }
+    
+    @Test
+    public void testContextInitializationDestruction() throws Exception
+    {
+        Server server = new Server();
+        ContextHandlerCollection contexts = new ContextHandlerCollection();
+        server.setHandler(contexts);
+
+        ContextHandler noServlets = new ContextHandler(contexts, "/noservlets");
+        TestServletContextListener listener = new TestServletContextListener();
+        noServlets.addEventListener(listener);
+        server.start();
+        assertEquals(1, listener.initialized);
+        server.stop();
+        assertEquals(1, listener.destroyed);
+    }
 
     @Test
     public void testContextVirtualGetContext() throws Exception
@@ -840,4 +859,22 @@ public class ContextHandlerTest
             writer.println("ctx='" + request.getContextPath() + "'");
         }
     }
+    
+    private static class TestServletContextListener implements ServletContextListener
+    {
+        public int initialized = 0;
+        public int destroyed = 0;
+        
+        @Override
+        public void contextInitialized(ServletContextEvent sce)
+        {
+            initialized++;
+        }
+
+        @Override
+        public void contextDestroyed(ServletContextEvent sce)
+        {
+            destroyed++;
+        }
+    }
 }
