@@ -26,6 +26,7 @@ import org.eclipse.jetty.util.log.Log;
 import org.eclipse.jetty.util.log.Logger;
 import org.eclipse.jetty.websocket.api.BatchMode;
 import org.eclipse.jetty.websocket.api.RemoteEndpoint;
+import org.eclipse.jetty.websocket.api.StatusCode;
 import org.eclipse.jetty.websocket.api.WebSocketAdapter;
 
 /**
@@ -38,6 +39,9 @@ public class JettyEchoSocket extends WebSocketAdapter
     @Override
     public void onWebSocketBinary(byte[] payload, int offset, int len)
     {
+        if (isNotConnected())
+            return;
+
         try
         {
             RemoteEndpoint remote = getRemote();
@@ -60,6 +64,9 @@ public class JettyEchoSocket extends WebSocketAdapter
     @Override
     public void onWebSocketText(String message)
     {
+        if (isNotConnected())
+            return;
+
         try
         {
             RemoteEndpoint remote = getRemote();
@@ -72,4 +79,14 @@ public class JettyEchoSocket extends WebSocketAdapter
             throw new RuntimeIOException(x);
         }
     }
+
+    @Override
+    public void onWebSocketClose(int statusCode, String reason)
+    {
+        super.onWebSocketClose(statusCode, reason);
+        if (statusCode != StatusCode.NORMAL)
+        {
+            LOG.warn("Closed {} {}", statusCode, reason);
+        }
+    }
 }
