@@ -53,19 +53,17 @@ public abstract class WebSocketHandler extends HandlerWrapper
         }
     }
 
-    private final WebSocketServletFactory webSocketFactory;
+    private final ByteBufferPool bufferPool;
+    private WebSocketServletFactory webSocketFactory;
 
     public WebSocketHandler()
     {
         this(new MappedByteBufferPool());
     }
-    
+
     public WebSocketHandler(ByteBufferPool bufferPool)
     {
-        WebSocketPolicy policy = new WebSocketPolicy(WebSocketBehavior.SERVER);
-        configurePolicy(policy);
-        webSocketFactory = new WebSocketServerFactory(policy, bufferPool);
-        addBean(webSocketFactory);
+        this.bufferPool = bufferPool;
     }
 
     public abstract void configure(WebSocketServletFactory factory);
@@ -78,22 +76,28 @@ public abstract class WebSocketHandler extends HandlerWrapper
     @Override
     protected void doStart() throws Exception
     {
+        WebSocketPolicy policy = new WebSocketPolicy(WebSocketBehavior.SERVER);
+        configurePolicy(policy);
+        webSocketFactory = new WebSocketServerFactory(policy, getServer().getThreadPool(), bufferPool);
+        addBean(webSocketFactory);
         configure(webSocketFactory);
         super.doStart();
     }
 
     public WebSocketServletFactory getWebSocketFactory()
     {
+        if (!isRunning())
+            throw new IllegalStateException("Not Started yet");
         return webSocketFactory;
     }
 
     @Override
     public void handle(String target, Request baseRequest, HttpServletRequest request, HttpServletResponse response) throws IOException, ServletException
     {
-        if (webSocketFactory.isUpgradeRequest(request,response))
+        if (webSocketFactory.isUpgradeRequest(request, response))
         {
             // We have an upgrade request
-            if (webSocketFactory.acceptWebSocket(request,response))
+            if (webSocketFactory.acceptWebSocket(request, response))
             {
                 // We have a socket instance created
                 baseRequest.setHandled(true);
@@ -108,6 +112,6 @@ public abstract class WebSocketHandler extends HandlerWrapper
                 return;
             }
         }
-        super.handle(target,baseRequest,request,response);
+        super.handle(target, baseRequest, request, response);
     }
 }
