@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2019 Mort Bay Consulting Pty. Ltd.
+//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -30,7 +30,6 @@ import java.util.concurrent.TimeUnit;
 import java.util.concurrent.TimeoutException;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicInteger;
-
 import javax.net.ssl.SSLEngine;
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
@@ -88,8 +87,8 @@ public class HttpClientTimeoutTest extends AbstractTest<TransportScenario>
         assertThrows(TimeoutException.class, () ->
         {
             scenario.client.newRequest(scenario.newURI())
-                    .timeout(timeout, TimeUnit.MILLISECONDS)
-                    .send();
+                .timeout(timeout, TimeUnit.MILLISECONDS)
+                .send();
         });
     }
 
@@ -103,7 +102,7 @@ public class HttpClientTimeoutTest extends AbstractTest<TransportScenario>
 
         final CountDownLatch latch = new CountDownLatch(1);
         Request request = scenario.client.newRequest(scenario.newURI())
-                .timeout(timeout, TimeUnit.MILLISECONDS);
+            .timeout(timeout, TimeUnit.MILLISECONDS);
         request.send(result ->
         {
             assertTrue(result.isFailed());
@@ -126,7 +125,7 @@ public class HttpClientTimeoutTest extends AbstractTest<TransportScenario>
         // The first request has a long timeout
         final CountDownLatch firstLatch = new CountDownLatch(1);
         Request request = scenario.client.newRequest(scenario.newURI())
-                .timeout(4 * timeout, TimeUnit.MILLISECONDS);
+            .timeout(4 * timeout, TimeUnit.MILLISECONDS);
         request.send(result ->
         {
             assertFalse(result.isFailed());
@@ -136,7 +135,7 @@ public class HttpClientTimeoutTest extends AbstractTest<TransportScenario>
         // Second request has a short timeout and should fail in the queue
         final CountDownLatch secondLatch = new CountDownLatch(1);
         request = scenario.client.newRequest(scenario.newURI())
-                .timeout(timeout, TimeUnit.MILLISECONDS);
+            .timeout(timeout, TimeUnit.MILLISECONDS);
         request.send(result ->
         {
             assertTrue(result.isFailed());
@@ -160,8 +159,8 @@ public class HttpClientTimeoutTest extends AbstractTest<TransportScenario>
         final CountDownLatch latch = new CountDownLatch(1);
         final byte[] content = {0, 1, 2, 3, 4, 5, 6, 7, 8, 9};
         Request request = scenario.client.newRequest(scenario.newURI())
-                .content(new InputStreamContentProvider(new ByteArrayInputStream(content)))
-                .timeout(2 * timeout, TimeUnit.MILLISECONDS);
+            .content(new InputStreamContentProvider(new ByteArrayInputStream(content)))
+            .timeout(2 * timeout, TimeUnit.MILLISECONDS);
         request.send(new BufferingResponseListener()
         {
             @Override
@@ -197,7 +196,7 @@ public class HttpClientTimeoutTest extends AbstractTest<TransportScenario>
         try (Connection connection = futureConnection.get(5, TimeUnit.SECONDS))
         {
             Request request = scenario.client.newRequest(scenario.newURI())
-                    .timeout(timeout, TimeUnit.MILLISECONDS);
+                .timeout(timeout, TimeUnit.MILLISECONDS);
             connection.send(request, result ->
             {
                 assertTrue(result.isFailed());
@@ -225,7 +224,7 @@ public class HttpClientTimeoutTest extends AbstractTest<TransportScenario>
         try (Connection connection = futureConnection.get(5, TimeUnit.SECONDS))
         {
             Request request = scenario.client.newRequest(scenario.newURI())
-                    .timeout(2 * timeout, TimeUnit.MILLISECONDS);
+                .timeout(2 * timeout, TimeUnit.MILLISECONDS);
             connection.send(request, result ->
             {
                 Response response = result.getResponse();
@@ -251,14 +250,15 @@ public class HttpClientTimeoutTest extends AbstractTest<TransportScenario>
         scenario.startServer(new TimeoutHandler(2 * timeout));
 
         AtomicBoolean sslIdle = new AtomicBoolean();
-        SslContextFactory sslContextFactory = scenario.newSslContextFactory();
-        sslContextFactory.setEndpointIdentificationAlgorithm(null);
+        SslContextFactory sslContextFactory = scenario.newClientSslContextFactory();
         scenario.client = new HttpClient(scenario.provideClientTransport(), sslContextFactory)
         {
             @Override
-            public ClientConnectionFactory newSslClientConnectionFactory(ClientConnectionFactory connectionFactory)
+            public ClientConnectionFactory newSslClientConnectionFactory(SslContextFactory sslContextFactory, ClientConnectionFactory connectionFactory)
             {
-                return new SslClientConnectionFactory(getSslContextFactory(), getByteBufferPool(), getExecutor(), connectionFactory)
+                if (sslContextFactory == null)
+                    sslContextFactory = getSslContextFactory();
+                return new SslClientConnectionFactory(sslContextFactory, getByteBufferPool(), getExecutor(), connectionFactory)
                 {
                     @Override
                     protected SslConnection newSslConnection(ByteBufferPool byteBufferPool, Executor executor, EndPoint endPoint, SSLEngine engine)
@@ -282,7 +282,7 @@ public class HttpClientTimeoutTest extends AbstractTest<TransportScenario>
         assertThrows(TimeoutException.class, () ->
         {
             scenario.client.newRequest(scenario.newURI())
-                    .send();
+                .send();
         });
         assertFalse(sslIdle.get());
     }
@@ -322,11 +322,11 @@ public class HttpClientTimeoutTest extends AbstractTest<TransportScenario>
         final CountDownLatch latch = new CountDownLatch(1);
         Request request = client.newRequest(host, port);
         request.scheme(scenario.getScheme())
-                .send(result ->
-                {
-                    if (result.isFailed())
-                        latch.countDown();
-                });
+            .send(result ->
+            {
+                if (result.isFailed())
+                    latch.countDown();
+            });
 
         assertTrue(latch.await(2 * connectTimeout, TimeUnit.MILLISECONDS));
         assertNotNull(request.getAbortCause());
@@ -354,12 +354,12 @@ public class HttpClientTimeoutTest extends AbstractTest<TransportScenario>
         final CountDownLatch latch = new CountDownLatch(2);
         Request request = client.newRequest(host, port);
         request.scheme(scenario.getScheme())
-                .timeout(connectTimeout / 2, TimeUnit.MILLISECONDS)
-                .send(result ->
-                {
-                    completes.incrementAndGet();
-                    latch.countDown();
-                });
+            .timeout(connectTimeout / 2, TimeUnit.MILLISECONDS)
+            .send(result ->
+            {
+                completes.incrementAndGet();
+                latch.countDown();
+            });
 
         assertFalse(latch.await(2 * connectTimeout, TimeUnit.MILLISECONDS));
         assertEquals(1, completes.get());
@@ -387,20 +387,20 @@ public class HttpClientTimeoutTest extends AbstractTest<TransportScenario>
         final CountDownLatch latch = new CountDownLatch(1);
         Request request = client.newRequest(host, port);
         request.scheme(scenario.getScheme())
-                .send(result ->
+            .send(result ->
+            {
+                if (result.isFailed())
                 {
-                    if (result.isFailed())
-                    {
-                        // Retry
-                        client.newRequest(host, port)
-                                .scheme(scenario.getScheme())
-                                .send(retryResult ->
-                                {
-                                    if (retryResult.isFailed())
-                                        latch.countDown();
-                                });
-                    }
-                });
+                    // Retry
+                    client.newRequest(host, port)
+                        .scheme(scenario.getScheme())
+                        .send(retryResult ->
+                        {
+                            if (retryResult.isFailed())
+                                latch.countDown();
+                        });
+                }
+            });
 
         assertTrue(latch.await(333 * connectTimeout, TimeUnit.MILLISECONDS));
         assertNotNull(request.getAbortCause());
@@ -415,8 +415,8 @@ public class HttpClientTimeoutTest extends AbstractTest<TransportScenario>
 
         final CountDownLatch latch = new CountDownLatch(1);
         scenario.client.newRequest(scenario.newURI())
-                .timeout(1, TimeUnit.MILLISECONDS) // Very short timeout
-                .send(result -> latch.countDown());
+            .timeout(1, TimeUnit.MILLISECONDS) // Very short timeout
+            .send(result -> latch.countDown());
 
         assertTrue(latch.await(5, TimeUnit.SECONDS));
     }
@@ -440,9 +440,9 @@ public class HttpClientTimeoutTest extends AbstractTest<TransportScenario>
         assertThrows(Exception.class, () ->
         {
             request.timeout(timeout, TimeUnit.MILLISECONDS)
-                    .send(result ->
-                    {
-                    });
+                .send(result ->
+                {
+                });
         });
 
         Thread.sleep(2 * timeout);
@@ -483,18 +483,18 @@ public class HttpClientTimeoutTest extends AbstractTest<TransportScenario>
 
         CountDownLatch latch = new CountDownLatch(1);
         scenario.client.newRequest(scenario.newURI())
-                .path("/one")
-                .timeout(2 * timeout, TimeUnit.MILLISECONDS)
-                .send(result ->
-                {
-                    if (result.isFailed() && result.getFailure() instanceof TimeoutException)
-                        latch.countDown();
-                });
+            .path("/one")
+            .timeout(2 * timeout, TimeUnit.MILLISECONDS)
+            .send(result ->
+            {
+                if (result.isFailed() && result.getFailure() instanceof TimeoutException)
+                    latch.countDown();
+            });
 
         ContentResponse response = scenario.client.newRequest(scenario.newURI())
-                .path("/two")
-                .timeout(timeout, TimeUnit.MILLISECONDS)
-                .send();
+            .path("/two")
+            .timeout(timeout, TimeUnit.MILLISECONDS)
+            .send();
 
         assertEquals(HttpStatus.OK_200, response.getStatus());
         assertTrue(latch.await(5, TimeUnit.SECONDS));
