@@ -1,6 +1,6 @@
 //
 //  ========================================================================
-//  Copyright (c) 1995-2019 Mort Bay Consulting Pty. Ltd.
+//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
 //  ------------------------------------------------------------------------
 //  All rights reserved. This program and the accompanying materials
 //  are made available under the terms of the Eclipse Public License v1.0
@@ -18,9 +18,6 @@
 
 package org.eclipse.jetty.test;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertTrue;
-
 import java.io.FileInputStream;
 import java.io.IOException;
 import java.net.Socket;
@@ -31,7 +28,6 @@ import java.util.Collections;
 import java.util.HashMap;
 import java.util.Map;
 import java.util.concurrent.TimeUnit;
-
 import javax.servlet.http.HttpServlet;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
@@ -66,52 +62,54 @@ import org.junit.jupiter.api.AfterAll;
 import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.Test;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+
 public class DigestPostTest
 {
     private static final String NC = "00000001";
-    
-    public final static String __message = 
-        "0123456789 0123456789 0123456789 0123456789 0123456789 0123456789 0123456789 0123456789 \n"+
-        "9876543210 9876543210 9876543210 9876543210 9876543210 9876543210 9876543210 9876543210 \n"+
-        "1234567890 1234567890 1234567890 1234567890 1234567890 1234567890 1234567890 1234567890 \n"+
-        "0987654321 0987654321 0987654321 0987654321 0987654321 0987654321 0987654321 0987654321 \n"+
-        "abcdefghijklmnopqrstuvwxyz abcdefghijklmnopqrstuvwxyz abcdefghijklmnopqrstuvwxyz \n"+
-        "ABCDEFGHIJKLMNOPQRSTUVWXYZ ABCDEFGHIJKLMNOPQRSTUVWXYZ ABCDEFGHIJKLMNOPQRSTUVWXYZ \n"+
-        "Now is the time for all good men to come to the aid of the party.\n"+
-        "How now brown cow.\n"+
-        "The quick brown fox jumped over the lazy dog.\n";
-    
-    public volatile static String _received = null;
+
+    public static final String __message =
+        "0123456789 0123456789 0123456789 0123456789 0123456789 0123456789 0123456789 0123456789 \n" +
+            "9876543210 9876543210 9876543210 9876543210 9876543210 9876543210 9876543210 9876543210 \n" +
+            "1234567890 1234567890 1234567890 1234567890 1234567890 1234567890 1234567890 1234567890 \n" +
+            "0987654321 0987654321 0987654321 0987654321 0987654321 0987654321 0987654321 0987654321 \n" +
+            "abcdefghijklmnopqrstuvwxyz abcdefghijklmnopqrstuvwxyz abcdefghijklmnopqrstuvwxyz \n" +
+            "ABCDEFGHIJKLMNOPQRSTUVWXYZ ABCDEFGHIJKLMNOPQRSTUVWXYZ ABCDEFGHIJKLMNOPQRSTUVWXYZ \n" +
+            "Now is the time for all good men to come to the aid of the party.\n" +
+            "How now brown cow.\n" +
+            "The quick brown fox jumped over the lazy dog.\n";
+
+    public static volatile String _received = null;
     private static Server _server;
 
     public static class TestLoginService extends AbstractLoginService
     {
         protected Map<String, UserPrincipal> users = new HashMap<>();
         protected Map<String, String[]> roles = new HashMap<>();
-     
-      
+
         public TestLoginService(String name)
         {
             setName(name);
         }
 
-        public void putUser (String username, Credential credential, String[] rolenames)
+        public void putUser(String username, Credential credential, String[] rolenames)
         {
-            UserPrincipal userPrincipal = new UserPrincipal(username,credential);
+            UserPrincipal userPrincipal = new UserPrincipal(username, credential);
             users.put(username, userPrincipal);
             roles.put(username, rolenames);
         }
-        
-        /** 
+
+        /**
          * @see org.eclipse.jetty.security.AbstractLoginService#loadRoleInfo(org.eclipse.jetty.security.AbstractLoginService.UserPrincipal)
          */
         @Override
         protected String[] loadRoleInfo(UserPrincipal user)
         {
-          return roles.get(user.getName());
+            return roles.get(user.getName());
         }
 
-        /** 
+        /**
          * @see org.eclipse.jetty.security.AbstractLoginService#loadUserInfo(java.lang.String)
          */
         @Override
@@ -120,41 +118,40 @@ public class DigestPostTest
             return users.get(username);
         }
     }
-    
-    
+
     @BeforeAll
     public static void setUpServer()
     {
         try
         {
             _server = new Server();
-            _server.setConnectors(new Connector[] { new ServerConnector(_server) });
+            _server.setConnectors(new Connector[]{new ServerConnector(_server)});
 
             ServletContextHandler context = new ServletContextHandler(ServletContextHandler.SECURITY);
             context.setContextPath("/test");
-            context.addServlet(PostServlet.class,"/");
+            context.addServlet(PostServlet.class, "/");
 
             TestLoginService realm = new TestLoginService("test");
-            realm.putUser("testuser",new Password("password"),new String[]{"test"});
+            realm.putUser("testuser", new Password("password"), new String[]{"test"});
             _server.addBean(realm);
-            
-            ConstraintSecurityHandler security=(ConstraintSecurityHandler)context.getSecurityHandler();
+
+            ConstraintSecurityHandler security = (ConstraintSecurityHandler)context.getSecurityHandler();
             security.setAuthenticator(new DigestAuthenticator());
             security.setLoginService(realm);
-           
-            Constraint constraint = new Constraint("SecureTest","test");
+
+            Constraint constraint = new Constraint("SecureTest", "test");
             constraint.setAuthenticate(true);
             ConstraintMapping mapping = new ConstraintMapping();
             mapping.setConstraint(constraint);
             mapping.setPathSpec("/*");
-            
+
             security.setConstraintMappings(Collections.singletonList(mapping));
-            
+
             HandlerCollection handlers = new HandlerCollection();
             handlers.setHandlers(new Handler[]
-            { context, new DefaultHandler() });
+                {context, new DefaultHandler()});
             _server.setHandler(handlers);
-            
+
             _server.start();
         }
         catch (final Exception e)
@@ -172,14 +169,14 @@ public class DigestPostTest
     @Test
     public void testServerDirectlyHTTP10() throws Exception
     {
-        Socket socket = new Socket("127.0.0.1",((NetworkConnector)_server.getConnectors()[0]).getLocalPort());
+        Socket socket = new Socket("127.0.0.1", ((NetworkConnector)_server.getConnectors()[0]).getLocalPort());
         byte[] bytes = __message.getBytes(StandardCharsets.UTF_8);
 
-        _received=null;
+        _received = null;
         socket.getOutputStream().write(
-                ("POST /test/ HTTP/1.0\r\n"+
-                "Host: 127.0.0.1:"+((NetworkConnector)_server.getConnectors()[0]).getLocalPort()+"\r\n"+
-                "Content-Length: "+bytes.length+"\r\n"+
+            ("POST /test/ HTTP/1.0\r\n" +
+                "Host: 127.0.0.1:" + ((NetworkConnector)_server.getConnectors()[0]).getLocalPort() + "\r\n" +
+                "Content-Length: " + bytes.length + "\r\n" +
                 "\r\n").getBytes(StandardCharsets.UTF_8));
         socket.getOutputStream().write(bytes);
         socket.getOutputStream().flush();
@@ -187,26 +184,25 @@ public class DigestPostTest
         String result = IO.toString(socket.getInputStream());
 
         assertTrue(result.startsWith("HTTP/1.1 401 Unauthorized"));
-        assertEquals(null,_received);
-        
-        int n=result.indexOf("nonce=");
-        String nonce=result.substring(n+7,result.indexOf('"',n+7));
-        MessageDigest md = MessageDigest.getInstance("MD5");
-        byte[] b= md.digest(String.valueOf(TimeUnit.NANOSECONDS.toMillis(System.nanoTime())).getBytes(org.eclipse.jetty.util.StringUtil.__ISO_8859_1));            
-        String cnonce=encode(b);
-        String digest="Digest username=\"testuser\" realm=\"test\" nonce=\""+nonce+"\" uri=\"/test/\" algorithm=MD5 response=\""+
-        newResponse("POST","/test/",cnonce,"testuser","test","password",nonce,"auth")+
-        "\" qop=auth nc="+NC+" cnonce=\""+cnonce+"\"";
-              
-        
-        socket = new Socket("127.0.0.1",((NetworkConnector)_server.getConnectors()[0]).getLocalPort());
+        assertEquals(null, _received);
 
-        _received=null;
+        int n = result.indexOf("nonce=");
+        String nonce = result.substring(n + 7, result.indexOf('"', n + 7));
+        MessageDigest md = MessageDigest.getInstance("MD5");
+        byte[] b = md.digest(String.valueOf(TimeUnit.NANOSECONDS.toMillis(System.nanoTime())).getBytes(org.eclipse.jetty.util.StringUtil.__ISO_8859_1));
+        String cnonce = encode(b);
+        String digest = "Digest username=\"testuser\" realm=\"test\" nonce=\"" + nonce + "\" uri=\"/test/\" algorithm=MD5 response=\"" +
+            newResponse("POST", "/test/", cnonce, "testuser", "test", "password", nonce, "auth") +
+            "\" qop=auth nc=" + NC + " cnonce=\"" + cnonce + "\"";
+
+        socket = new Socket("127.0.0.1", ((NetworkConnector)_server.getConnectors()[0]).getLocalPort());
+
+        _received = null;
         socket.getOutputStream().write(
-                ("POST /test/ HTTP/1.0\r\n"+
-                "Host: 127.0.0.1:"+((NetworkConnector)_server.getConnectors()[0]).getLocalPort()+"\r\n"+
-                "Content-Length: "+bytes.length+"\r\n"+
-                "Authorization: "+digest+"\r\n"+
+            ("POST /test/ HTTP/1.0\r\n" +
+                "Host: 127.0.0.1:" + ((NetworkConnector)_server.getConnectors()[0]).getLocalPort() + "\r\n" +
+                "Content-Length: " + bytes.length + "\r\n" +
+                "Authorization: " + digest + "\r\n" +
                 "\r\n").getBytes(StandardCharsets.UTF_8));
         socket.getOutputStream().write(bytes);
         socket.getOutputStream().flush();
@@ -214,48 +210,48 @@ public class DigestPostTest
         result = IO.toString(socket.getInputStream());
 
         assertTrue(result.startsWith("HTTP/1.1 200 OK"));
-        assertEquals(__message,_received);
+        assertEquals(__message, _received);
     }
 
     @Test
     public void testServerDirectlyHTTP11() throws Exception
     {
-        Socket socket = new Socket("127.0.0.1",((NetworkConnector)_server.getConnectors()[0]).getLocalPort());
+        Socket socket = new Socket("127.0.0.1", ((NetworkConnector)_server.getConnectors()[0]).getLocalPort());
         byte[] bytes = __message.getBytes(StandardCharsets.UTF_8);
 
-        _received=null;
+        _received = null;
         socket.getOutputStream().write(
-                ("POST /test/ HTTP/1.1\r\n"+
-                "Host: 127.0.0.1:"+((NetworkConnector)_server.getConnectors()[0]).getLocalPort()+"\r\n"+
-                "Content-Length: "+bytes.length+"\r\n"+
+            ("POST /test/ HTTP/1.1\r\n" +
+                "Host: 127.0.0.1:" + ((NetworkConnector)_server.getConnectors()[0]).getLocalPort() + "\r\n" +
+                "Content-Length: " + bytes.length + "\r\n" +
                 "\r\n").getBytes("UTF-8"));
         socket.getOutputStream().write(bytes);
         socket.getOutputStream().flush();
 
         Thread.sleep(100);
-        
-        byte[] buf=new byte[4096];
-        int len=socket.getInputStream().read(buf);
-        String result=new String(buf,0,len,StandardCharsets.UTF_8);
+
+        byte[] buf = new byte[4096];
+        int len = socket.getInputStream().read(buf);
+        String result = new String(buf, 0, len, StandardCharsets.UTF_8);
 
         assertTrue(result.startsWith("HTTP/1.1 401 Unauthorized"));
-        assertEquals(null,_received);
-        
-        int n=result.indexOf("nonce=");
-        String nonce=result.substring(n+7,result.indexOf('"',n+7));
-        MessageDigest md = MessageDigest.getInstance("MD5");
-        byte[] b= md.digest(String.valueOf(TimeUnit.NANOSECONDS.toMillis(System.nanoTime())).getBytes(StringUtil.__ISO_8859_1));            
-        String cnonce=encode(b);
-        String digest="Digest username=\"testuser\" realm=\"test\" nonce=\""+nonce+"\" uri=\"/test/\" algorithm=MD5 response=\""+
-        newResponse("POST","/test/",cnonce,"testuser","test","password",nonce,"auth")+
-        "\" qop=auth nc="+NC+" cnonce=\""+cnonce+"\"";
+        assertEquals(null, _received);
 
-        _received=null;
+        int n = result.indexOf("nonce=");
+        String nonce = result.substring(n + 7, result.indexOf('"', n + 7));
+        MessageDigest md = MessageDigest.getInstance("MD5");
+        byte[] b = md.digest(String.valueOf(TimeUnit.NANOSECONDS.toMillis(System.nanoTime())).getBytes(StringUtil.__ISO_8859_1));
+        String cnonce = encode(b);
+        String digest = "Digest username=\"testuser\" realm=\"test\" nonce=\"" + nonce + "\" uri=\"/test/\" algorithm=MD5 response=\"" +
+            newResponse("POST", "/test/", cnonce, "testuser", "test", "password", nonce, "auth") +
+            "\" qop=auth nc=" + NC + " cnonce=\"" + cnonce + "\"";
+
+        _received = null;
         socket.getOutputStream().write(
-                ("POST /test/ HTTP/1.0\r\n"+
-                "Host: 127.0.0.1:"+((NetworkConnector)_server.getConnectors()[0]).getLocalPort()+"\r\n"+
-                "Content-Length: "+bytes.length+"\r\n"+
-                "Authorization: "+digest+"\r\n"+
+            ("POST /test/ HTTP/1.0\r\n" +
+                "Host: 127.0.0.1:" + ((NetworkConnector)_server.getConnectors()[0]).getLocalPort() + "\r\n" +
+                "Content-Length: " + bytes.length + "\r\n" +
+                "Authorization: " + digest + "\r\n" +
                 "\r\n").getBytes("UTF-8"));
         socket.getOutputStream().write(bytes);
         socket.getOutputStream().flush();
@@ -263,13 +259,13 @@ public class DigestPostTest
         result = IO.toString(socket.getInputStream());
 
         assertTrue(result.startsWith("HTTP/1.1 200 OK"));
-        assertEquals(__message,_received);
+        assertEquals(__message, _received);
     }
 
     @Test
     public void testServerWithHttpClientStringContent() throws Exception
     {
-        String srvUrl = "http://127.0.0.1:" + ((NetworkConnector)_server.getConnectors()[0]).getLocalPort() + "/test/";        
+        String srvUrl = "http://127.0.0.1:" + ((NetworkConnector)_server.getConnectors()[0]).getLocalPort() + "/test/";
         HttpClient client = new HttpClient();
 
         try
@@ -281,11 +277,11 @@ public class DigestPostTest
             Request request = client.newRequest(srvUrl);
             request.method(HttpMethod.POST);
             request.content(new BytesContentProvider(__message.getBytes("UTF8")));
-            _received=null;
+            _received = null;
             request = request.timeout(5, TimeUnit.SECONDS);
             ContentResponse response = request.send();
-            assertEquals(__message,_received);
-            assertEquals(200,response.getStatus());
+            assertEquals(__message, _received);
+            assertEquals(200, response.getStatus());
         }
         finally
         {
@@ -296,26 +292,25 @@ public class DigestPostTest
     @Test
     public void testServerWithHttpClientStreamContent() throws Exception
     {
-        String srvUrl = "http://127.0.0.1:" + ((NetworkConnector)_server.getConnectors()[0]).getLocalPort() + "/test/";       
+        String srvUrl = "http://127.0.0.1:" + ((NetworkConnector)_server.getConnectors()[0]).getLocalPort() + "/test/";
         HttpClient client = new HttpClient();
         try
         {
             AuthenticationStore authStore = client.getAuthenticationStore();
-            authStore.addAuthentication(new DigestAuthentication(new URI(srvUrl), "test", "testuser", "password"));   
+            authStore.addAuthentication(new DigestAuthentication(new URI(srvUrl), "test", "testuser", "password"));
             client.start();
 
             String sent = IO.toString(new FileInputStream("src/test/resources/message.txt"));
-            
+
             Request request = client.newRequest(srvUrl);
             request.method(HttpMethod.POST);
             request.content(new StringContentProvider(sent));
-            _received=null;
+            _received = null;
             request = request.timeout(5, TimeUnit.SECONDS);
             ContentResponse response = request.send();
-           
-            assertEquals(200,response.getStatus());
-            assertEquals(sent,_received);
 
+            assertEquals(200, response.getStatus());
+            assertEquals(sent, _received);
         }
         finally
         {
@@ -323,8 +318,6 @@ public class DigestPostTest
         }
     }
 
- 
-
     public static class PostServlet extends HttpServlet
     {
         private static final long serialVersionUID = 1L;
@@ -337,14 +330,13 @@ public class DigestPostTest
             _received = received;
 
             response.setStatus(200);
-            response.getWriter().println("Received "+received.length()+" bytes");
+            response.getWriter().println("Received " + received.length() + " bytes");
         }
-
     }
 
     protected String newResponse(String method, String uri, String cnonce, String principal, String realm, String credentials, String nonce, String qop)
         throws Exception
-    {       
+    {
         MessageDigest md = MessageDigest.getInstance("MD5");
 
         // calc A1 digest
@@ -359,9 +351,9 @@ public class DigestPostTest
         md.update(method.getBytes(StringUtil.__ISO_8859_1));
         md.update((byte)':');
         md.update(uri.getBytes(StringUtil.__ISO_8859_1));
-        byte[] ha2=md.digest();
+        byte[] ha2 = md.digest();
 
-        md.update(TypeUtil.toString(ha1,16).getBytes(StringUtil.__ISO_8859_1));
+        md.update(TypeUtil.toString(ha1, 16).getBytes(StringUtil.__ISO_8859_1));
         md.update((byte)':');
         md.update(nonce.getBytes(StringUtil.__ISO_8859_1));
         md.update((byte)':');
@@ -371,17 +363,17 @@ public class DigestPostTest
         md.update((byte)':');
         md.update(qop.getBytes(StringUtil.__ISO_8859_1));
         md.update((byte)':');
-        md.update(TypeUtil.toString(ha2,16).getBytes(StringUtil.__ISO_8859_1));
-        byte[] digest=md.digest();
+        md.update(TypeUtil.toString(ha2, 16).getBytes(StringUtil.__ISO_8859_1));
+        byte[] digest = md.digest();
 
         // check digest
         return encode(digest);
     }
-    
+
     private static String encode(byte[] data)
     {
         StringBuffer buffer = new StringBuffer();
-        for (int i=0; i<data.length; i++) 
+        for (int i = 0; i < data.length; i++)
         {
             buffer.append(Integer.toHexString((data[i] & 0xf0) >>> 4));
             buffer.append(Integer.toHexString(data[i] & 0x0f));
