@@ -18,13 +18,10 @@
 
 package org.eclipse.jetty.server.session;
 
-import java.util.ArrayList;
-import java.util.List;
-
 import org.eclipse.jetty.servlet.ServletContextHandler;
+import org.eclipse.jetty.session.infinispan.InfinispanSessionData;
 import org.eclipse.jetty.session.infinispan.InfinispanSessionDataStore;
 import org.eclipse.jetty.session.infinispan.InfinispanSessionDataStoreFactory;
-import org.infinispan.Cache;
 import org.infinispan.query.Search;
 import org.infinispan.query.dsl.Query;
 import org.infinispan.query.dsl.QueryFactory;
@@ -32,9 +29,8 @@ import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 
-import static org.junit.jupiter.api.Assertions.assertFalse;
-import static org.junit.jupiter.api.Assertions.assertTrue;
-import static org.junit.jupiter.api.Assertions.fail;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertThrows;
 
 /**
  * InfinispanSessionDataStoreTest
@@ -110,15 +106,7 @@ public class InfinispanSessionDataStoreTest extends AbstractSessionDataStoreTest
         ((InfinispanSessionDataStore)store).setCache(null);
 
         //test that loading it fails
-        try
-        {
-            store.load("222");
-            fail("Session should be unreadable");
-        }
-        catch (UnreadableSessionDataException e)
-        {
-            //expected exception
-        }
+        assertThrows(UnreadableSessionDataException.class, () -> store.load("222"));
     }
 
     /**
@@ -164,30 +152,26 @@ public class InfinispanSessionDataStoreTest extends AbstractSessionDataStoreTest
     @Test
     public void testQuery() throws Exception
     {
-        Cache<String, SessionData> cache = _testSupport.getCache();
+        InfinispanSessionData sd1 = new InfinispanSessionData("sd1", "", "", 0, 0, 0, 1000);
+        sd1.setLastNode("fred1");
+        _testSupport.getCache().put("session1", sd1);
 
-        SessionData sd1 = new SessionData("sd1", "", "", 0, 0, 0, 0);
-        SessionData sd2 = new SessionData("sd2", "", "", 0, 0, 0, 1000);
-        sd2.setExpiry(100L); //long ago
-        SessionData sd3 = new SessionData("sd3", "", "", 0, 0, 0, 0);
+        InfinispanSessionData sd2 = new InfinispanSessionData("sd2", "", "", 0, 0, 0, 2000);
+        sd2.setLastNode("fred2");
+        _testSupport.getCache().put("session2", sd2);
 
-        cache.put("session1", sd1);
-        cache.put("session2", sd2);
-        cache.put("session3", sd3);
+        InfinispanSessionData sd3 = new InfinispanSessionData("sd3", "", "", 0, 0, 0, 3000);
+        sd3.setLastNode("fred3");
+        _testSupport.getCache().put("session3", sd3);
 
-        QueryFactory qf = Search.getQueryFactory(cache);
-        Query q = qf.from(SessionData.class).select("id").having("expiry").lte(System.currentTimeMillis()).and().having("expiry").gt(0).toBuilder().build();
+        QueryFactory qf = Search.getQueryFactory(_testSupport.getCache());
 
-        List<Object[]> list = q.list();
-
-        List<String> ids = new ArrayList<>();
-        for (Object[] sl : list)
+        for (int i = 0; i <= 3; i++)
         {
-            ids.add((String)sl[0]);
+            long now = System.currentTimeMillis();
+            Query q = qf.from(InfinispanSessionData.class).having("expiry").lt(now).build();
+            assertEquals(i, q.list().size());
+            Thread.sleep(1000);
         }
-
-        assertFalse(ids.isEmpty());
-        assertTrue(1 == ids.size());
-        assertTrue(ids.contains("sd2"));
     }
 }
